@@ -15,7 +15,7 @@
 #
 
 # flake8: noqa
-from .base_operator import BaseOperator, Supports
-from .graph import Graph
-from .node import Node, iter_nodes, postorder_iter_nodes, preorder_iter_nodes
-from .selector import ColumnSelector
+from merlin.dag.base_operator import BaseOperator, Supports
+from merlin.dag.graph import Graph
+from merlin.dag.node import Node, iter_nodes, postorder_iter_nodes, preorder_iter_nodes
+from merlin.dag.selector import ColumnSelector
