@@ -24,10 +24,9 @@ from dask.highlevelgraph import HighLevelGraph
 
 from merlin.core.dispatch import annotate
 from merlin.core.utils import ensure_optimize_dataframe_graph, global_dask_client
+from merlin.io.shuffle import Shuffle
 from merlin.io.worker import clean_worker_cache, get_worker_cache
-
-from .shuffle import Shuffle
-from .writer_factory import _writer_cls_factory, writer_factory
+from merlin.io.writer_factory import _writer_cls_factory, writer_factory
 
 
 class DaskSubgraph:
